"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EthClient = void 0;
const assert_1 = __importDefault(require("assert"));
const ethers_1 = require("ethers");
class EthClient {
    constructor(provider) {
        this.provider = provider;
    }
    static dial(chainUrl) {
        // Connect to the Ethereum provider
        const provider = new ethers_1.ethers.providers.WebSocketProvider(chainUrl);
        return new EthClient(provider);
    }
    transactionByHash(transactionHash) {
        return __awaiter(this, void 0, void 0, function* () {
            (0, assert_1.default)(this.provider);
            // Get transaction by hash
            const transaction = yield this.provider.getTransaction(transactionHash);
            return transaction;
        });
    }
    chainID() {
        return __awaiter(this, void 0, void 0, function* () {
            (0, assert_1.default)(this.provider);
            // Get chain ID
            const network = yield this.provider.getNetwork();
            return BigInt(network.chainId);
        });
    }
    subscribeFilterLogs(filter, callback) {
        (0, assert_1.default)(this.provider);
        // Subscribe to filtered logs
        const listener = (log) => {
            callback(log);
        };
        this.provider.on(filter, listener);
        return listener;
    }
}
exports.EthClient = EthClient;
//# sourceMappingURL=eth-client.js.map